@@ -2,17 +2,18 @@
 import itertools
 import logging
 import psycopg2
+import psycopg2.extras
 import re
 
-__version__ = VERSION = version = '0.0.5'
-version_info = (0, 0, 5)
+__version__ = VERSION = version = '0.0.6'
+version_info = (0, 0, 6)
 
 
 class Connection(object):
-    def __init__(self, host_or_url, database=None, user=None, password=None, port=5432):
+    def __init__(self, host_or_url="127.0.0.1", database=None, user=None, password=None, port=5432):
         self.logging = False
         if host_or_url.startswith('postgres://'):
-            args = re.search('postgres://(?P<user>[\w\-]+):?(?P<password>[\w\-]*)@(?P<host>.*):(?P<port>\d+)/(?P<database>[\w\-]+)', host_or_url).groupdict()
+            args = re.search('postgres://(?P<user>[\w\-]*):?(?P<password>[\w\-]*)@(?P<host>[\w\-\.]+):?(?P<port>\d+)/?(?P<database>[\w\-]+)', host_or_url).groupdict()
             self.host = args.get('host')
             self.database = args.get('database')
         else:
@@ -43,6 +44,13 @@ class Connection(object):
         self.close()
         self._db = psycopg2.connect(**self._db_args)
         self._db.autocommit = True
+        try:
+            psycopg2.extras.register_hstore(self._db, globally=True)
+        except psycopg2.ProgrammingError:
+            pass
+
+    def hstore(self, dict):
+        return ','.join(['"%s"=>"%s"' % (str(k), str(v)) for k, v in dict.items()])
 
     def mogrify(self, query, *parameters):
         """From http://initd.org/psycopg/docs/cursor.html?highlight=mogrify#cursor.mogrify
